from hatchet_sdk.runnables.workflow import Workflow
from pydantic import BaseModel, HttpUrl
from fastapi import FastAPI
from typer import Typer


class Plugin(BaseModel):
    id: str
    module: str
    description: str


class APIPlugin(Plugin):
    _api: FastAPI


class CLIPlugin(Plugin):
    _cli: Typer


class WorkflowPlugin(Plugin):
    _wf: Workflow


class SettingsPlugin(Plugin): ...


class Plugins(BaseModel):
    api: dict[str, APIPlugin] = {}
    cli: dict[str, CLIPlugin] = {}
    workflow: dict[str, WorkflowPlugin] = {}
    settings: dict[str, SettingsPlugin] = {}


class ServerInfo(BaseModel):
    version: str
    hatchet_url: HttpUrl
    api_doc: str
    plugins: Plugins = Plugins()
