import logging
from importlib.metadata import entry_points

from hatchet_sdk.runnables.workflow import Workflow

from knoc.workflows.foo import foo_wf
from knoc.models import WorkflowPlugin

logger = logging.getLogger("knoc.workflows")

all_wfs: dict[str, Workflow] = {"knoc.workflows:foo": foo_wf}

wfs_settings: dict[str, WorkflowPlugin] = {}


def get_plugins(workflows: dict[str, Workflow]):
    for entry_point in entry_points().select(group="knoc.workflow"):
        try:
            wf = entry_point.load()
        except Exception as err:
            logger.warning(f"Cannot load CLI module {entry_point.name} - see below")
            logger.exception(err)
            continue
        if not isinstance(wf, Workflow):
            logger.warning(f"CLI module {entry_point.name} is not a Typer")
            continue
        wfs_settings[entry_point.value] = WorkflowPlugin(
            id=entry_point.name,
            module=entry_point.module,
            description=wf.name.capitalize().replace("-", " "),
            _wf=wf,
        )
        workflows[entry_point.value] = wf


get_plugins(all_wfs)
